<?php
/**
 * EventController class
 *
 * PHP version 5
 *
 * @category ADPOI
 * @package  Api.controller
 * @author   Pohil Alexandr <pohil@5-soft.com>
 * @license  http://adpoi.com/display/license proprietary
 * @link     http://adpoi.com/display/PhpDoc
 */
/**
 * EventController is the controller class
 * for managing Event records
 *
 * @category ADPOI
 * @package  Api.controller
 * @author   Pohil Alexandr <pohil@5-soft.com>
 * @license  http://adpoi.com/display/license proprietary
 * @link     http://adpoi.com/display/PhpDoc
 */
class EventController extends RestApiController
{
    /**
     * Returns controller's actions' filters
     * 
     * @return array action filters
     */
    public function filters()
    {
        return array(
            'validInput',
            'accessControl',
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * 
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('allow',
                'users' => array('*'),
            ),
            array('deny',
               'users' => array('*'),
            ),
        );
    }
    
    /**
     * Returns api methods' models configuration
     * 
     * @return api models configuration
     * @see RestApiController::models()
     */
    public function models()
    {
        $user = Yii::app()->user;
        return array(
            'list' => array(
                'class' => 'EventApiModel',
                'scenario' => 'list',
                'criteria' => array(
                    'with' => array('poi', 'creator'),
                ),
            ),
            'show' => array(
                'class' => 'EventApiModel',
                'scenario' => 'show',
                'criteria' => array(
                    'with' => array('poi', 'creator'),
                ),
            ),
            'create' => array(
                'class' => 'EventApiModel',
                'scenario' => 'create',
                'creator_id' => $user->isGuest ? null : $user->logged->id,
            ),
            'update' => array(
                'class' => 'EventApiModel',
                'scenario' => 'update',
            ),
            'delete' => array(
                'class' => 'EventApiModel',
                'scenario' => 'delete',
            ),
        );
    }
    
    /**
     * Returns attached actions configuration
     * 
     * @return array attached actions
     * @see CController::actions()
     */
    public function actions()
    {
        return array(
            'create' => array(
                'class' => 'RestApiCreateMethod',
                'responseMap' => array(
                    'id' => 'event',
                ),
            ),
            'update' => array(
                'class' => 'RestApiUpdateMethod',
            ),
            'show' => array(
                'class' => 'RestApiShowMethod',
                'responseMap' => array(
                    'exp:$data->poi->id' => 'poi',
                    'name' => '#',
                    'exp:$data->creator->name' => 'creator',
                    'start_time' => 'start_time',
                    'end_time' => 'end_time',
                    'description' => '#',
                ),
            ),
            'delete' => array(
                'class' => 'RestApiDeleteMethod',
            ),
           'list' => array(
                'class' => 'RestApiListMethod',
                'responseMap' => array(
                     '*' => array(
                        'id' => 'event',
                        'name' => '#',
                        'exp:$data->poi->id' => 'poi',
                        'exp:$data->poi->name' => 'poi_name',
                        'exp:$data->creator->name' => 'creator',
                        'start_time' => 'start_time',
                        'end_time' => 'end_time',
                        'state' => '#'
                    ),
                ),
            ),
        );
    }
}
